"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var index_1 = require("./index");
describe('Utils', function () {
    var obj = {
        a: 'Hello',
        b: 'World!',
        c: {
            name: "welcome",
            text: "Welcome To",
            font: { family: 'Open Sans', style: 'bold' }
        },
        d: ['is', 'json', 'pick', 'keys']
    };
    describe('inclusion', function () {
        it('should pick keys picked for inclusion', function () {
            var pickedKeys = index_1.default(obj, 'a b c');
            expect(pickedKeys).toHaveProperty('a');
            expect(pickedKeys).toHaveProperty('b');
            expect(pickedKeys).toHaveProperty('c');
            expect(pickedKeys).not.toHaveProperty('d');
        });
        it('should deep pick keys picked for inclusion', function () {
            var pickedKeys = index_1.default(obj, 'c.font.style');
            expect(pickedKeys).toHaveProperty('c');
            expect(pickedKeys['c']).not.toHaveProperty('name');
            expect(pickedKeys['c']).not.toHaveProperty('text');
            expect(pickedKeys['c']['font']).toHaveProperty('style');
            expect(pickedKeys['c']['font']).not.toHaveProperty('family');
        });
    });
    describe('exclusion', function () {
        it('should deselect keys picked for exclusion', function () {
            var pickedKeys = index_1.default(obj, '-a -c');
            expect(pickedKeys).not.toHaveProperty('a');
            expect(pickedKeys).toHaveProperty('b');
            expect(pickedKeys).not.toHaveProperty('c');
            expect(pickedKeys).toHaveProperty('d');
        });
        it('should deep deselect keys picked for exclusion', function () {
            var pickedKeys = index_1.default(obj, '-c.font.style');
            expect(pickedKeys).toHaveProperty('a');
            expect(pickedKeys).toHaveProperty('b');
            expect(pickedKeys).toHaveProperty('d');
            expect(pickedKeys).toHaveProperty('c');
            expect(pickedKeys['c']).toHaveProperty('name');
            expect(pickedKeys['c']).toHaveProperty('text');
            expect(pickedKeys['c']['font']).not.toHaveProperty('style');
            expect(pickedKeys['c']['font']).toHaveProperty('family');
        });
    });
    describe('pick', function () {
        it('should select keys for inclusion and deselect for exclusion', function () {
            var pickedKeys = index_1.default(obj, '-a -c b');
            expect(pickedKeys).not.toHaveProperty('a');
            expect(pickedKeys).toHaveProperty('b');
            expect(pickedKeys).not.toHaveProperty('c');
            expect(pickedKeys).not.toHaveProperty('d');
        });
        it('should deep deselect keys picked for exclusion', function () {
            var pickedKeys = index_1.default(obj, 'a b -d -c.font.style c');
            expect(pickedKeys).toHaveProperty('a');
            expect(pickedKeys).toHaveProperty('b');
            expect(pickedKeys).not.toHaveProperty('d');
            expect(pickedKeys).toHaveProperty('c');
            expect(pickedKeys['c']).toHaveProperty('name');
            expect(pickedKeys['c']).toHaveProperty('text');
            expect(pickedKeys['c']['font']).not.toHaveProperty('style');
            expect(pickedKeys['c']['font']).toHaveProperty('family');
        });
    });
});
